# harbor1_client

Harbor1Client - the Ruby gem for the [Harbor 1 API](https://github.com/goharbor/harbor/blob/v1.10.6/api/harbor/swagger.yaml).

These APIs provide services for manipulating Harbor projects.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.10.0
- Package version: 0.1.1
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build harbor1_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./harbor1_client-0.1.1.gem
```
(for development, run `gem install --dev ./harbor1_client-0.1.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'harbor1_client', '~> 0.1.1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO, then add the following in the Gemfile:

    gem 'harbor1_client', :git => 'https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'harbor1_client'

# Setup authorization
Harbor1Client.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = Harbor1Client::ChartRepositoryApi.new

chart = File.new('/path/to/file.txt') # File | The chart file

opts = { 
  prov: File.new('/path/to/file.txt') # File | The provance file
}

begin
  #Upload a chart file to the defult 'library' project.
  api_instance.chartrepo_charts_post(chart, opts)
rescue Harbor1Client::ApiError => e
  puts "Exception when calling ChartRepositoryApi->chartrepo_charts_post: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_charts_post**](docs/ChartRepositoryApi.md#chartrepo_charts_post) | **POST** /chartrepo/charts | Upload a chart file to the defult 'library' project.
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_health_get**](docs/ChartRepositoryApi.md#chartrepo_health_get) | **GET** /chartrepo/health | Check the health of chart repository service.
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_get**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_get) | **GET** /chartrepo/{repo}/charts | Get all the charts under the specified project
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_name_delete**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_name_delete) | **DELETE** /chartrepo/{repo}/charts/{name} | Delete all the versions of the specified chart
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_name_get**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_name_get) | **GET** /chartrepo/{repo}/charts/{name} | Get all the versions of the specified chart
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_name_version_delete**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_name_version_delete) | **DELETE** /chartrepo/{repo}/charts/{name}/{version} | Delete the specified chart version
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_name_version_get**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_name_version_get) | **GET** /chartrepo/{repo}/charts/{name}/{version} | Get the specified chart version
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_name_version_labels_get**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_name_version_labels_get) | **GET** /chartrepo/{repo}/charts/{name}/{version}/labels | Return the attahced labels of chart.
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_name_version_labels_id_delete**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_name_version_labels_id_delete) | **DELETE** /chartrepo/{repo}/charts/{name}/{version}/labels/{id} | Remove label from chart.
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_name_version_labels_post**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_name_version_labels_post) | **POST** /chartrepo/{repo}/charts/{name}/{version}/labels | Mark label to chart.
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_charts_post**](docs/ChartRepositoryApi.md#chartrepo_repo_charts_post) | **POST** /chartrepo/{repo}/charts | Upload a chart file to the specified project.
*Harbor1Client::ChartRepositoryApi* | [**chartrepo_repo_prov_post**](docs/ChartRepositoryApi.md#chartrepo_repo_prov_post) | **POST** /chartrepo/{repo}/prov | Upload a provance file to the specified project.
*Harbor1Client::LabelApi* | [**chartrepo_repo_charts_name_version_labels_get**](docs/LabelApi.md#chartrepo_repo_charts_name_version_labels_get) | **GET** /chartrepo/{repo}/charts/{name}/{version}/labels | Return the attahced labels of chart.
*Harbor1Client::LabelApi* | [**chartrepo_repo_charts_name_version_labels_id_delete**](docs/LabelApi.md#chartrepo_repo_charts_name_version_labels_id_delete) | **DELETE** /chartrepo/{repo}/charts/{name}/{version}/labels/{id} | Remove label from chart.
*Harbor1Client::LabelApi* | [**chartrepo_repo_charts_name_version_labels_post**](docs/LabelApi.md#chartrepo_repo_charts_name_version_labels_post) | **POST** /chartrepo/{repo}/charts/{name}/{version}/labels | Mark label to chart.
*Harbor1Client::ProductsApi* | [**chartrepo_charts_post**](docs/ProductsApi.md#chartrepo_charts_post) | **POST** /chartrepo/charts | Upload a chart file to the defult 'library' project.
*Harbor1Client::ProductsApi* | [**chartrepo_health_get**](docs/ProductsApi.md#chartrepo_health_get) | **GET** /chartrepo/health | Check the health of chart repository service.
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_get**](docs/ProductsApi.md#chartrepo_repo_charts_get) | **GET** /chartrepo/{repo}/charts | Get all the charts under the specified project
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_name_delete**](docs/ProductsApi.md#chartrepo_repo_charts_name_delete) | **DELETE** /chartrepo/{repo}/charts/{name} | Delete all the versions of the specified chart
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_name_get**](docs/ProductsApi.md#chartrepo_repo_charts_name_get) | **GET** /chartrepo/{repo}/charts/{name} | Get all the versions of the specified chart
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_name_version_delete**](docs/ProductsApi.md#chartrepo_repo_charts_name_version_delete) | **DELETE** /chartrepo/{repo}/charts/{name}/{version} | Delete the specified chart version
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_name_version_get**](docs/ProductsApi.md#chartrepo_repo_charts_name_version_get) | **GET** /chartrepo/{repo}/charts/{name}/{version} | Get the specified chart version
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_name_version_labels_get**](docs/ProductsApi.md#chartrepo_repo_charts_name_version_labels_get) | **GET** /chartrepo/{repo}/charts/{name}/{version}/labels | Return the attahced labels of chart.
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_name_version_labels_id_delete**](docs/ProductsApi.md#chartrepo_repo_charts_name_version_labels_id_delete) | **DELETE** /chartrepo/{repo}/charts/{name}/{version}/labels/{id} | Remove label from chart.
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_name_version_labels_post**](docs/ProductsApi.md#chartrepo_repo_charts_name_version_labels_post) | **POST** /chartrepo/{repo}/charts/{name}/{version}/labels | Mark label to chart.
*Harbor1Client::ProductsApi* | [**chartrepo_repo_charts_post**](docs/ProductsApi.md#chartrepo_repo_charts_post) | **POST** /chartrepo/{repo}/charts | Upload a chart file to the specified project.
*Harbor1Client::ProductsApi* | [**chartrepo_repo_prov_post**](docs/ProductsApi.md#chartrepo_repo_prov_post) | **POST** /chartrepo/{repo}/prov | Upload a provance file to the specified project.
*Harbor1Client::ProductsApi* | [**configurations_get**](docs/ProductsApi.md#configurations_get) | **GET** /configurations | Get system configurations.
*Harbor1Client::ProductsApi* | [**configurations_put**](docs/ProductsApi.md#configurations_put) | **PUT** /configurations | Modify system configurations.
*Harbor1Client::ProductsApi* | [**email_ping_post**](docs/ProductsApi.md#email_ping_post) | **POST** /email/ping | Test connection and authentication with email server.
*Harbor1Client::ProductsApi* | [**health_get**](docs/ProductsApi.md#health_get) | **GET** /health | Health check API
*Harbor1Client::ProductsApi* | [**internal_switchquota_put**](docs/ProductsApi.md#internal_switchquota_put) | **PUT** /internal/switchquota | Enable or disable quota.
*Harbor1Client::ProductsApi* | [**internal_syncquota_post**](docs/ProductsApi.md#internal_syncquota_post) | **POST** /internal/syncquota | Sync quota from registry/chart to DB.
*Harbor1Client::ProductsApi* | [**internal_syncregistry_post**](docs/ProductsApi.md#internal_syncregistry_post) | **POST** /internal/syncregistry | Sync repositories from registry to DB.
*Harbor1Client::ProductsApi* | [**labels_get**](docs/ProductsApi.md#labels_get) | **GET** /labels | List labels according to the query strings.
*Harbor1Client::ProductsApi* | [**labels_id_delete**](docs/ProductsApi.md#labels_id_delete) | **DELETE** /labels/{id} | Delete the label specified by ID.
*Harbor1Client::ProductsApi* | [**labels_id_get**](docs/ProductsApi.md#labels_id_get) | **GET** /labels/{id} | Get the label specified by ID.
*Harbor1Client::ProductsApi* | [**labels_id_put**](docs/ProductsApi.md#labels_id_put) | **PUT** /labels/{id} | Update the label properties.
*Harbor1Client::ProductsApi* | [**labels_id_resources_get**](docs/ProductsApi.md#labels_id_resources_get) | **GET** /labels/{id}/resources | Get the resources that the label is referenced by.
*Harbor1Client::ProductsApi* | [**labels_post**](docs/ProductsApi.md#labels_post) | **POST** /labels | Post creates a label
*Harbor1Client::ProductsApi* | [**ldap_groups_search_get**](docs/ProductsApi.md#ldap_groups_search_get) | **GET** /ldap/groups/search | Search available ldap groups.
*Harbor1Client::ProductsApi* | [**ldap_ping_post**](docs/ProductsApi.md#ldap_ping_post) | **POST** /ldap/ping | Ping available ldap service.
*Harbor1Client::ProductsApi* | [**ldap_users_import_post**](docs/ProductsApi.md#ldap_users_import_post) | **POST** /ldap/users/import | Import selected available ldap users.
*Harbor1Client::ProductsApi* | [**ldap_users_search_get**](docs/ProductsApi.md#ldap_users_search_get) | **GET** /ldap/users/search | Search available ldap users.
*Harbor1Client::ProductsApi* | [**logs_get**](docs/ProductsApi.md#logs_get) | **GET** /logs | Get recent logs of the projects which the user is a member of
*Harbor1Client::ProductsApi* | [**projects_get**](docs/ProductsApi.md#projects_get) | **GET** /projects | List projects
*Harbor1Client::ProductsApi* | [**projects_head**](docs/ProductsApi.md#projects_head) | **HEAD** /projects | Check if the project name user provided already exists.
*Harbor1Client::ProductsApi* | [**projects_post**](docs/ProductsApi.md#projects_post) | **POST** /projects | Create a new project.
*Harbor1Client::ProductsApi* | [**projects_project_id_delete**](docs/ProductsApi.md#projects_project_id_delete) | **DELETE** /projects/{project_id} | Delete project by projectID
*Harbor1Client::ProductsApi* | [**projects_project_id_get**](docs/ProductsApi.md#projects_project_id_get) | **GET** /projects/{project_id} | Return specific project detail information
*Harbor1Client::ProductsApi* | [**projects_project_id_immutabletagrules_get**](docs/ProductsApi.md#projects_project_id_immutabletagrules_get) | **GET** /projects/{project_id}/immutabletagrules | List all immutable tag rules of current project
*Harbor1Client::ProductsApi* | [**projects_project_id_immutabletagrules_id_delete**](docs/ProductsApi.md#projects_project_id_immutabletagrules_id_delete) | **DELETE** /projects/{project_id}/immutabletagrules/{id} | Delete the immutable tag rule.
*Harbor1Client::ProductsApi* | [**projects_project_id_immutabletagrules_id_put**](docs/ProductsApi.md#projects_project_id_immutabletagrules_id_put) | **PUT** /projects/{project_id}/immutabletagrules/{id} | Update the immutable tag rule or enable or disable the rule
*Harbor1Client::ProductsApi* | [**projects_project_id_immutabletagrules_post**](docs/ProductsApi.md#projects_project_id_immutabletagrules_post) | **POST** /projects/{project_id}/immutabletagrules | Add an immutable tag rule to current project
*Harbor1Client::ProductsApi* | [**projects_project_id_logs_get**](docs/ProductsApi.md#projects_project_id_logs_get) | **GET** /projects/{project_id}/logs | Get access logs accompany with a relevant project.
*Harbor1Client::ProductsApi* | [**projects_project_id_members_get**](docs/ProductsApi.md#projects_project_id_members_get) | **GET** /projects/{project_id}/members | Get all project member information
*Harbor1Client::ProductsApi* | [**projects_project_id_members_mid_delete**](docs/ProductsApi.md#projects_project_id_members_mid_delete) | **DELETE** /projects/{project_id}/members/{mid} | Delete project member
*Harbor1Client::ProductsApi* | [**projects_project_id_members_mid_get**](docs/ProductsApi.md#projects_project_id_members_mid_get) | **GET** /projects/{project_id}/members/{mid} | Get the project member information
*Harbor1Client::ProductsApi* | [**projects_project_id_members_mid_put**](docs/ProductsApi.md#projects_project_id_members_mid_put) | **PUT** /projects/{project_id}/members/{mid} | Update project member
*Harbor1Client::ProductsApi* | [**projects_project_id_members_post**](docs/ProductsApi.md#projects_project_id_members_post) | **POST** /projects/{project_id}/members | Create project member
*Harbor1Client::ProductsApi* | [**projects_project_id_metadatas_get**](docs/ProductsApi.md#projects_project_id_metadatas_get) | **GET** /projects/{project_id}/metadatas | Get project metadata.
*Harbor1Client::ProductsApi* | [**projects_project_id_metadatas_meta_name_delete**](docs/ProductsApi.md#projects_project_id_metadatas_meta_name_delete) | **DELETE** /projects/{project_id}/metadatas/{meta_name} | Delete metadata of a project
*Harbor1Client::ProductsApi* | [**projects_project_id_metadatas_meta_name_get**](docs/ProductsApi.md#projects_project_id_metadatas_meta_name_get) | **GET** /projects/{project_id}/metadatas/{meta_name} | Get project metadata
*Harbor1Client::ProductsApi* | [**projects_project_id_metadatas_meta_name_put**](docs/ProductsApi.md#projects_project_id_metadatas_meta_name_put) | **PUT** /projects/{project_id}/metadatas/{meta_name} | Update metadata of a project.
*Harbor1Client::ProductsApi* | [**projects_project_id_metadatas_post**](docs/ProductsApi.md#projects_project_id_metadatas_post) | **POST** /projects/{project_id}/metadatas | Add metadata for the project.
*Harbor1Client::ProductsApi* | [**projects_project_id_put**](docs/ProductsApi.md#projects_project_id_put) | **PUT** /projects/{project_id} | Update properties for a selected project.
*Harbor1Client::ProductsApi* | [**projects_project_id_robots_get**](docs/ProductsApi.md#projects_project_id_robots_get) | **GET** /projects/{project_id}/robots | Get all robot accounts of specified project
*Harbor1Client::ProductsApi* | [**projects_project_id_robots_post**](docs/ProductsApi.md#projects_project_id_robots_post) | **POST** /projects/{project_id}/robots | Create a robot account for project
*Harbor1Client::ProductsApi* | [**projects_project_id_robots_robot_id_delete**](docs/ProductsApi.md#projects_project_id_robots_robot_id_delete) | **DELETE** /projects/{project_id}/robots/{robot_id} | Delete the specified robot account
*Harbor1Client::ProductsApi* | [**projects_project_id_robots_robot_id_get**](docs/ProductsApi.md#projects_project_id_robots_robot_id_get) | **GET** /projects/{project_id}/robots/{robot_id} | Return the infor of the specified robot account.
*Harbor1Client::ProductsApi* | [**projects_project_id_robots_robot_id_put**](docs/ProductsApi.md#projects_project_id_robots_robot_id_put) | **PUT** /projects/{project_id}/robots/{robot_id} | Update status of robot account.
*Harbor1Client::ProductsApi* | [**projects_project_id_scanner_candidates_get**](docs/ProductsApi.md#projects_project_id_scanner_candidates_get) | **GET** /projects/{project_id}/scanner/candidates | Get scanner registration candidates for configurating project level scanner
*Harbor1Client::ProductsApi* | [**projects_project_id_scanner_get**](docs/ProductsApi.md#projects_project_id_scanner_get) | **GET** /projects/{project_id}/scanner | Get project level scanner
*Harbor1Client::ProductsApi* | [**projects_project_id_summary_get**](docs/ProductsApi.md#projects_project_id_summary_get) | **GET** /projects/{project_id}/summary | Get summary of the project.
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_jobs_get**](docs/ProductsApi.md#projects_project_id_webhook_jobs_get) | **GET** /projects/{project_id}/webhook/jobs | List project webhook jobs
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_lasttrigger_get**](docs/ProductsApi.md#projects_project_id_webhook_lasttrigger_get) | **GET** /projects/{project_id}/webhook/lasttrigger | Get project webhook policy last trigger info
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_policies_get**](docs/ProductsApi.md#projects_project_id_webhook_policies_get) | **GET** /projects/{project_id}/webhook/policies | List project webhook policies.
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_policies_policy_id_delete**](docs/ProductsApi.md#projects_project_id_webhook_policies_policy_id_delete) | **DELETE** /projects/{project_id}/webhook/policies/{policy_id} | Delete webhook policy of a project
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_policies_policy_id_get**](docs/ProductsApi.md#projects_project_id_webhook_policies_policy_id_get) | **GET** /projects/{project_id}/webhook/policies/{policy_id} | Get project webhook policy
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_policies_policy_id_put**](docs/ProductsApi.md#projects_project_id_webhook_policies_policy_id_put) | **PUT** /projects/{project_id}/webhook/policies/{policy_id} | Update webhook policy of a project.
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_policies_post**](docs/ProductsApi.md#projects_project_id_webhook_policies_post) | **POST** /projects/{project_id}/webhook/policies | Create project webhook policy.
*Harbor1Client::ProductsApi* | [**projects_project_id_webhook_policies_test_post**](docs/ProductsApi.md#projects_project_id_webhook_policies_test_post) | **POST** /projects/{project_id}/webhook/policies/test | Test project webhook connection
*Harbor1Client::ProductsApi* | [**quotas_get**](docs/ProductsApi.md#quotas_get) | **GET** /quotas | List quotas
*Harbor1Client::ProductsApi* | [**quotas_id_get**](docs/ProductsApi.md#quotas_id_get) | **GET** /quotas/{id} | Get the specified quota
*Harbor1Client::ProductsApi* | [**quotas_id_put**](docs/ProductsApi.md#quotas_id_put) | **PUT** /quotas/{id} | Update the specified quota
*Harbor1Client::ProductsApi* | [**registries_get**](docs/ProductsApi.md#registries_get) | **GET** /registries | List registries.
*Harbor1Client::ProductsApi* | [**registries_id_delete**](docs/ProductsApi.md#registries_id_delete) | **DELETE** /registries/{id} | Delete specific registry.
*Harbor1Client::ProductsApi* | [**registries_id_get**](docs/ProductsApi.md#registries_id_get) | **GET** /registries/{id} | Get registry.
*Harbor1Client::ProductsApi* | [**registries_id_info_get**](docs/ProductsApi.md#registries_id_info_get) | **GET** /registries/{id}/info | Get registry info.
*Harbor1Client::ProductsApi* | [**registries_id_namespace_get**](docs/ProductsApi.md#registries_id_namespace_get) | **GET** /registries/{id}/namespace | List namespaces of registry
*Harbor1Client::ProductsApi* | [**registries_id_put**](docs/ProductsApi.md#registries_id_put) | **PUT** /registries/{id} | Update a given registry.
*Harbor1Client::ProductsApi* | [**registries_ping_post**](docs/ProductsApi.md#registries_ping_post) | **POST** /registries/ping | Ping status of a registry.
*Harbor1Client::ProductsApi* | [**registries_post**](docs/ProductsApi.md#registries_post) | **POST** /registries | Create a new registry.
*Harbor1Client::ProductsApi* | [**replication_adapters_get**](docs/ProductsApi.md#replication_adapters_get) | **GET** /replication/adapters | List supported adapters.
*Harbor1Client::ProductsApi* | [**replication_executions_get**](docs/ProductsApi.md#replication_executions_get) | **GET** /replication/executions | List replication executions.
*Harbor1Client::ProductsApi* | [**replication_executions_id_get**](docs/ProductsApi.md#replication_executions_id_get) | **GET** /replication/executions/{id} | Get the execution of the replication.
*Harbor1Client::ProductsApi* | [**replication_executions_id_put**](docs/ProductsApi.md#replication_executions_id_put) | **PUT** /replication/executions/{id} | Stop the execution of the replication.
*Harbor1Client::ProductsApi* | [**replication_executions_id_tasks_get**](docs/ProductsApi.md#replication_executions_id_tasks_get) | **GET** /replication/executions/{id}/tasks | Get the task list of one execution.
*Harbor1Client::ProductsApi* | [**replication_executions_id_tasks_task_id_log_get**](docs/ProductsApi.md#replication_executions_id_tasks_task_id_log_get) | **GET** /replication/executions/{id}/tasks/{task_id}/log | Get the log of one task.
*Harbor1Client::ProductsApi* | [**replication_executions_post**](docs/ProductsApi.md#replication_executions_post) | **POST** /replication/executions | Start one execution of the replication.
*Harbor1Client::ProductsApi* | [**replication_policies_get**](docs/ProductsApi.md#replication_policies_get) | **GET** /replication/policies | List replication policies
*Harbor1Client::ProductsApi* | [**replication_policies_id_delete**](docs/ProductsApi.md#replication_policies_id_delete) | **DELETE** /replication/policies/{id} | Delete the replication policy specified by ID.
*Harbor1Client::ProductsApi* | [**replication_policies_id_get**](docs/ProductsApi.md#replication_policies_id_get) | **GET** /replication/policies/{id} | Get replication policy.
*Harbor1Client::ProductsApi* | [**replication_policies_id_put**](docs/ProductsApi.md#replication_policies_id_put) | **PUT** /replication/policies/{id} | Update the replication policy
*Harbor1Client::ProductsApi* | [**replication_policies_post**](docs/ProductsApi.md#replication_policies_post) | **POST** /replication/policies | Create a replication policy
*Harbor1Client::ProductsApi* | [**repositories_get**](docs/ProductsApi.md#repositories_get) | **GET** /repositories | Get repositories accompany with relevant project and repo name.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_delete**](docs/ProductsApi.md#repositories_repo_name_delete) | **DELETE** /repositories/{repo_name} | Delete a repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_labels_get**](docs/ProductsApi.md#repositories_repo_name_labels_get) | **GET** /repositories/{repo_name}/labels | Get labels of a repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_labels_label_id_delete**](docs/ProductsApi.md#repositories_repo_name_labels_label_id_delete) | **DELETE** /repositories/{repo_name}/labels/{label_id} | Delete label from the repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_labels_post**](docs/ProductsApi.md#repositories_repo_name_labels_post) | **POST** /repositories/{repo_name}/labels | Add a label to the repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_put**](docs/ProductsApi.md#repositories_repo_name_put) | **PUT** /repositories/{repo_name} | Update description of the repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_signatures_get**](docs/ProductsApi.md#repositories_repo_name_signatures_get) | **GET** /repositories/{repo_name}/signatures | Get signature information of a repository
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_get**](docs/ProductsApi.md#repositories_repo_name_tags_get) | **GET** /repositories/{repo_name}/tags | Get tags of a relevant repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_post**](docs/ProductsApi.md#repositories_repo_name_tags_post) | **POST** /repositories/{repo_name}/tags | Retag an image
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_delete**](docs/ProductsApi.md#repositories_repo_name_tags_tag_delete) | **DELETE** /repositories/{repo_name}/tags/{tag} | Delete a tag in a repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_get**](docs/ProductsApi.md#repositories_repo_name_tags_tag_get) | **GET** /repositories/{repo_name}/tags/{tag} | Get the tag of the repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_labels_get**](docs/ProductsApi.md#repositories_repo_name_tags_tag_labels_get) | **GET** /repositories/{repo_name}/tags/{tag}/labels | Get labels of an image.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_labels_label_id_delete**](docs/ProductsApi.md#repositories_repo_name_tags_tag_labels_label_id_delete) | **DELETE** /repositories/{repo_name}/tags/{tag}/labels/{label_id} | Delete label from the image.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_labels_post**](docs/ProductsApi.md#repositories_repo_name_tags_tag_labels_post) | **POST** /repositories/{repo_name}/tags/{tag}/labels | Add a label to image.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_manifest_get**](docs/ProductsApi.md#repositories_repo_name_tags_tag_manifest_get) | **GET** /repositories/{repo_name}/tags/{tag}/manifest | Get manifests of a relevant repository.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_scan_post**](docs/ProductsApi.md#repositories_repo_name_tags_tag_scan_post) | **POST** /repositories/{repo_name}/tags/{tag}/scan | Scan the image.
*Harbor1Client::ProductsApi* | [**repositories_repo_name_tags_tag_scan_uuid_log_get**](docs/ProductsApi.md#repositories_repo_name_tags_tag_scan_uuid_log_get) | **GET** /repositories/{repo_name}/tags/{tag}/scan/{uuid}/log | Get scan log
*Harbor1Client::ProductsApi* | [**repositories_top_get**](docs/ProductsApi.md#repositories_top_get) | **GET** /repositories/top | Get public repositories which are accessed most.
*Harbor1Client::ProductsApi* | [**retentions_id_executions_eid_patch**](docs/ProductsApi.md#retentions_id_executions_eid_patch) | **PATCH** /retentions/{id}/executions/{eid} | Stop a Retention job
*Harbor1Client::ProductsApi* | [**retentions_id_executions_eid_tasks_get**](docs/ProductsApi.md#retentions_id_executions_eid_tasks_get) | **GET** /retentions/{id}/executions/{eid}/tasks | Get Retention job tasks
*Harbor1Client::ProductsApi* | [**retentions_id_executions_eid_tasks_tid_get**](docs/ProductsApi.md#retentions_id_executions_eid_tasks_tid_get) | **GET** /retentions/{id}/executions/{eid}/tasks/{tid} | Get Retention job task log
*Harbor1Client::ProductsApi* | [**retentions_id_executions_get**](docs/ProductsApi.md#retentions_id_executions_get) | **GET** /retentions/{id}/executions | Get a Retention job
*Harbor1Client::ProductsApi* | [**retentions_id_executions_post**](docs/ProductsApi.md#retentions_id_executions_post) | **POST** /retentions/{id}/executions | Trigger a Retention job
*Harbor1Client::ProductsApi* | [**retentions_id_get**](docs/ProductsApi.md#retentions_id_get) | **GET** /retentions/{id} | Get Retention Policy
*Harbor1Client::ProductsApi* | [**retentions_id_put**](docs/ProductsApi.md#retentions_id_put) | **PUT** /retentions/{id} | Update Retention Policy
*Harbor1Client::ProductsApi* | [**retentions_metadatas_get**](docs/ProductsApi.md#retentions_metadatas_get) | **GET** /retentions/metadatas | Get Retention Metadatas
*Harbor1Client::ProductsApi* | [**retentions_post**](docs/ProductsApi.md#retentions_post) | **POST** /retentions | Create Retention Policy
*Harbor1Client::ProductsApi* | [**scanners_get**](docs/ProductsApi.md#scanners_get) | **GET** /scanners | List scanner registrations
*Harbor1Client::ProductsApi* | [**scanners_ping_post**](docs/ProductsApi.md#scanners_ping_post) | **POST** /scanners/ping | Tests scanner registration settings
*Harbor1Client::ProductsApi* | [**scanners_registration_id_get**](docs/ProductsApi.md#scanners_registration_id_get) | **GET** /scanners/{registration_id} | Get a scanner registration details
*Harbor1Client::ProductsApi* | [**scanners_registration_id_metadata_get**](docs/ProductsApi.md#scanners_registration_id_metadata_get) | **GET** /scanners/{registration_id}/metadata | Get the metadata of the specified scanner registration
*Harbor1Client::ProductsApi* | [**scans_all_metrics_get**](docs/ProductsApi.md#scans_all_metrics_get) | **GET** /scans/all/metrics | Get the metrics of the latest scan all process
*Harbor1Client::ProductsApi* | [**scans_schedule_metrics_get**](docs/ProductsApi.md#scans_schedule_metrics_get) | **GET** /scans/schedule/metrics | Get the metrics of the latest scheduled scan all process
*Harbor1Client::ProductsApi* | [**search_get**](docs/ProductsApi.md#search_get) | **GET** /search | Search for projects, repositories and helm charts
*Harbor1Client::ProductsApi* | [**statistics_get**](docs/ProductsApi.md#statistics_get) | **GET** /statistics | Get projects number and repositories number relevant to the user
*Harbor1Client::ProductsApi* | [**system_cve_whitelist_get**](docs/ProductsApi.md#system_cve_whitelist_get) | **GET** /system/CVEWhitelist | Get the system level whitelist of CVE.
*Harbor1Client::ProductsApi* | [**system_cve_whitelist_put**](docs/ProductsApi.md#system_cve_whitelist_put) | **PUT** /system/CVEWhitelist | Update the system level whitelist of CVE.
*Harbor1Client::ProductsApi* | [**system_gc_get**](docs/ProductsApi.md#system_gc_get) | **GET** /system/gc | Get gc results.
*Harbor1Client::ProductsApi* | [**system_gc_id_get**](docs/ProductsApi.md#system_gc_id_get) | **GET** /system/gc/{id} | Get gc status.
*Harbor1Client::ProductsApi* | [**system_gc_id_log_get**](docs/ProductsApi.md#system_gc_id_log_get) | **GET** /system/gc/{id}/log | Get gc job log.
*Harbor1Client::ProductsApi* | [**system_gc_schedule_get**](docs/ProductsApi.md#system_gc_schedule_get) | **GET** /system/gc/schedule | Get gc's schedule.
*Harbor1Client::ProductsApi* | [**system_gc_schedule_post**](docs/ProductsApi.md#system_gc_schedule_post) | **POST** /system/gc/schedule | Create a gc schedule.
*Harbor1Client::ProductsApi* | [**system_gc_schedule_put**](docs/ProductsApi.md#system_gc_schedule_put) | **PUT** /system/gc/schedule | Update gc's schedule.
*Harbor1Client::ProductsApi* | [**system_oidc_ping_post**](docs/ProductsApi.md#system_oidc_ping_post) | **POST** /system/oidc/ping | Test the OIDC endpoint.
*Harbor1Client::ProductsApi* | [**system_scan_all_schedule_get**](docs/ProductsApi.md#system_scan_all_schedule_get) | **GET** /system/scanAll/schedule | Get scan_all's schedule.
*Harbor1Client::ProductsApi* | [**system_scan_all_schedule_post**](docs/ProductsApi.md#system_scan_all_schedule_post) | **POST** /system/scanAll/schedule | Create a schedule or a manual trigger for the scan all job.
*Harbor1Client::ProductsApi* | [**system_scan_all_schedule_put**](docs/ProductsApi.md#system_scan_all_schedule_put) | **PUT** /system/scanAll/schedule | Update scan all's schedule.
*Harbor1Client::ProductsApi* | [**systeminfo_get**](docs/ProductsApi.md#systeminfo_get) | **GET** /systeminfo | Get general system info
*Harbor1Client::ProductsApi* | [**systeminfo_getcert_get**](docs/ProductsApi.md#systeminfo_getcert_get) | **GET** /systeminfo/getcert | Get default root certificate.
*Harbor1Client::ProductsApi* | [**systeminfo_volumes_get**](docs/ProductsApi.md#systeminfo_volumes_get) | **GET** /systeminfo/volumes | Get system volume info (total/free size).
*Harbor1Client::ProductsApi* | [**usergroups_get**](docs/ProductsApi.md#usergroups_get) | **GET** /usergroups | Get all user groups information
*Harbor1Client::ProductsApi* | [**usergroups_group_id_delete**](docs/ProductsApi.md#usergroups_group_id_delete) | **DELETE** /usergroups/{group_id} | Delete user group
*Harbor1Client::ProductsApi* | [**usergroups_group_id_get**](docs/ProductsApi.md#usergroups_group_id_get) | **GET** /usergroups/{group_id} | Get user group information
*Harbor1Client::ProductsApi* | [**usergroups_group_id_put**](docs/ProductsApi.md#usergroups_group_id_put) | **PUT** /usergroups/{group_id} | Update group information
*Harbor1Client::ProductsApi* | [**usergroups_post**](docs/ProductsApi.md#usergroups_post) | **POST** /usergroups | Create user group
*Harbor1Client::ProductsApi* | [**users_current_get**](docs/ProductsApi.md#users_current_get) | **GET** /users/current | Get current user info.
*Harbor1Client::ProductsApi* | [**users_current_permissions_get**](docs/ProductsApi.md#users_current_permissions_get) | **GET** /users/current/permissions | Get current user permissions.
*Harbor1Client::ProductsApi* | [**users_get**](docs/ProductsApi.md#users_get) | **GET** /users | Get registered users of Harbor.
*Harbor1Client::ProductsApi* | [**users_post**](docs/ProductsApi.md#users_post) | **POST** /users | Creates a new user account.
*Harbor1Client::ProductsApi* | [**users_search_get**](docs/ProductsApi.md#users_search_get) | **GET** /users/search | Search users by username
*Harbor1Client::ProductsApi* | [**users_user_id_cli_secret_put**](docs/ProductsApi.md#users_user_id_cli_secret_put) | **PUT** /users/{user_id}/cli_secret | Set CLI secret for a user.
*Harbor1Client::ProductsApi* | [**users_user_id_delete**](docs/ProductsApi.md#users_user_id_delete) | **DELETE** /users/{user_id} | Mark a registered user as be removed.
*Harbor1Client::ProductsApi* | [**users_user_id_get**](docs/ProductsApi.md#users_user_id_get) | **GET** /users/{user_id} | Get a user's profile.
*Harbor1Client::ProductsApi* | [**users_user_id_password_put**](docs/ProductsApi.md#users_user_id_password_put) | **PUT** /users/{user_id}/password | Change the password on a user that already exists.
*Harbor1Client::ProductsApi* | [**users_user_id_put**](docs/ProductsApi.md#users_user_id_put) | **PUT** /users/{user_id} | Update a registered user to change his profile.
*Harbor1Client::ProductsApi* | [**users_user_id_sysadmin_put**](docs/ProductsApi.md#users_user_id_sysadmin_put) | **PUT** /users/{user_id}/sysadmin | Update a registered user to change to be an administrator of Harbor.
*Harbor1Client::QuotaApi* | [**quotas_id_get**](docs/QuotaApi.md#quotas_id_get) | **GET** /quotas/{id} | Get the specified quota
*Harbor1Client::QuotaApi* | [**quotas_id_put**](docs/QuotaApi.md#quotas_id_put) | **PUT** /quotas/{id} | Update the specified quota
*Harbor1Client::RetentionApi* | [**retentions_id_executions_eid_patch**](docs/RetentionApi.md#retentions_id_executions_eid_patch) | **PATCH** /retentions/{id}/executions/{eid} | Stop a Retention job
*Harbor1Client::RetentionApi* | [**retentions_id_executions_eid_tasks_get**](docs/RetentionApi.md#retentions_id_executions_eid_tasks_get) | **GET** /retentions/{id}/executions/{eid}/tasks | Get Retention job tasks
*Harbor1Client::RetentionApi* | [**retentions_id_executions_eid_tasks_tid_get**](docs/RetentionApi.md#retentions_id_executions_eid_tasks_tid_get) | **GET** /retentions/{id}/executions/{eid}/tasks/{tid} | Get Retention job task log
*Harbor1Client::RetentionApi* | [**retentions_id_executions_get**](docs/RetentionApi.md#retentions_id_executions_get) | **GET** /retentions/{id}/executions | Get a Retention job
*Harbor1Client::RetentionApi* | [**retentions_id_executions_post**](docs/RetentionApi.md#retentions_id_executions_post) | **POST** /retentions/{id}/executions | Trigger a Retention job
*Harbor1Client::RetentionApi* | [**retentions_id_get**](docs/RetentionApi.md#retentions_id_get) | **GET** /retentions/{id} | Get Retention Policy
*Harbor1Client::RetentionApi* | [**retentions_metadatas_get**](docs/RetentionApi.md#retentions_metadatas_get) | **GET** /retentions/metadatas | Get Retention Metadatas
*Harbor1Client::RetentionApi* | [**retentions_post**](docs/RetentionApi.md#retentions_post) | **POST** /retentions | Create Retention Policy
*Harbor1Client::RobotAccountApi* | [**projects_project_id_robots_get**](docs/RobotAccountApi.md#projects_project_id_robots_get) | **GET** /projects/{project_id}/robots | Get all robot accounts of specified project
*Harbor1Client::RobotAccountApi* | [**projects_project_id_robots_post**](docs/RobotAccountApi.md#projects_project_id_robots_post) | **POST** /projects/{project_id}/robots | Create a robot account for project
*Harbor1Client::RobotAccountApi* | [**projects_project_id_robots_robot_id_delete**](docs/RobotAccountApi.md#projects_project_id_robots_robot_id_delete) | **DELETE** /projects/{project_id}/robots/{robot_id} | Delete the specified robot account
*Harbor1Client::RobotAccountApi* | [**projects_project_id_robots_robot_id_get**](docs/RobotAccountApi.md#projects_project_id_robots_robot_id_get) | **GET** /projects/{project_id}/robots/{robot_id} | Return the infor of the specified robot account.
*Harbor1Client::RobotAccountApi* | [**projects_project_id_robots_robot_id_put**](docs/RobotAccountApi.md#projects_project_id_robots_robot_id_put) | **PUT** /projects/{project_id}/robots/{robot_id} | Update status of robot account.
*Harbor1Client::ScanApi* | [**repositories_repo_name_tags_tag_scan_get**](docs/ScanApi.md#repositories_repo_name_tags_tag_scan_get) | **GET** /repositories/{repo_name}/tags/{tag}/scan | Get the scan report
*Harbor1Client::ScanApi* | [**repositories_repo_name_tags_tag_scan_post**](docs/ScanApi.md#repositories_repo_name_tags_tag_scan_post) | **POST** /repositories/{repo_name}/tags/{tag}/scan | Scan the image.
*Harbor1Client::ScanApi* | [**repositories_repo_name_tags_tag_scan_uuid_log_get**](docs/ScanApi.md#repositories_repo_name_tags_tag_scan_uuid_log_get) | **GET** /repositories/{repo_name}/tags/{tag}/scan/{uuid}/log | Get scan log
*Harbor1Client::ScanApi* | [**scans_all_metrics_get**](docs/ScanApi.md#scans_all_metrics_get) | **GET** /scans/all/metrics | Get the metrics of the latest scan all process
*Harbor1Client::ScanApi* | [**scans_schedule_metrics_get**](docs/ScanApi.md#scans_schedule_metrics_get) | **GET** /scans/schedule/metrics | Get the metrics of the latest scheduled scan all process
*Harbor1Client::ScannersApi* | [**projects_project_id_scanner_candidates_get**](docs/ScannersApi.md#projects_project_id_scanner_candidates_get) | **GET** /projects/{project_id}/scanner/candidates | Get scanner registration candidates for configurating project level scanner
*Harbor1Client::ScannersApi* | [**projects_project_id_scanner_get**](docs/ScannersApi.md#projects_project_id_scanner_get) | **GET** /projects/{project_id}/scanner | Get project level scanner
*Harbor1Client::ScannersApi* | [**projects_project_id_scanner_put**](docs/ScannersApi.md#projects_project_id_scanner_put) | **PUT** /projects/{project_id}/scanner | Configure scanner for the specified project
*Harbor1Client::ScannersApi* | [**scanners_get**](docs/ScannersApi.md#scanners_get) | **GET** /scanners | List scanner registrations
*Harbor1Client::ScannersApi* | [**scanners_ping_post**](docs/ScannersApi.md#scanners_ping_post) | **POST** /scanners/ping | Tests scanner registration settings
*Harbor1Client::ScannersApi* | [**scanners_post**](docs/ScannersApi.md#scanners_post) | **POST** /scanners | Create a scanner registration
*Harbor1Client::ScannersApi* | [**scanners_registration_id_delete**](docs/ScannersApi.md#scanners_registration_id_delete) | **DELETE** /scanners/{registration_id} | Delete a scanner registration
*Harbor1Client::ScannersApi* | [**scanners_registration_id_get**](docs/ScannersApi.md#scanners_registration_id_get) | **GET** /scanners/{registration_id} | Get a scanner registration details
*Harbor1Client::ScannersApi* | [**scanners_registration_id_metadata_get**](docs/ScannersApi.md#scanners_registration_id_metadata_get) | **GET** /scanners/{registration_id}/metadata | Get the metadata of the specified scanner registration
*Harbor1Client::ScannersApi* | [**scanners_registration_id_patch**](docs/ScannersApi.md#scanners_registration_id_patch) | **PATCH** /scanners/{registration_id} | Set system default scanner registration
*Harbor1Client::ScannersApi* | [**scanners_registration_id_put**](docs/ScannersApi.md#scanners_registration_id_put) | **PUT** /scanners/{registration_id} | Update a scanner registration
*Harbor1Client::SystemApi* | [**system_cve_whitelist_get**](docs/SystemApi.md#system_cve_whitelist_get) | **GET** /system/CVEWhitelist | Get the system level whitelist of CVE.
*Harbor1Client::SystemApi* | [**system_cve_whitelist_put**](docs/SystemApi.md#system_cve_whitelist_put) | **PUT** /system/CVEWhitelist | Update the system level whitelist of CVE.
*Harbor1Client::SystemApi* | [**system_oidc_ping_post**](docs/SystemApi.md#system_oidc_ping_post) | **POST** /system/oidc/ping | Test the OIDC endpoint.


## Documentation for Models

 - [Harbor1Client::AccessLog](docs/AccessLog.md)
 - [Harbor1Client::Action](docs/Action.md)
 - [Harbor1Client::Action1](docs/Action1.md)
 - [Harbor1Client::AdminJobSchedule](docs/AdminJobSchedule.md)
 - [Harbor1Client::AdminJobScheduleObj](docs/AdminJobScheduleObj.md)
 - [Harbor1Client::BadRequestFormatedError](docs/BadRequestFormatedError.md)
 - [Harbor1Client::BoolConfigItem](docs/BoolConfigItem.md)
 - [Harbor1Client::CVEWhitelist](docs/CVEWhitelist.md)
 - [Harbor1Client::CVEWhitelistItem](docs/CVEWhitelistItem.md)
 - [Harbor1Client::ChartAPIError](docs/ChartAPIError.md)
 - [Harbor1Client::ChartInfoEntry](docs/ChartInfoEntry.md)
 - [Harbor1Client::ChartInfoList](docs/ChartInfoList.md)
 - [Harbor1Client::ChartMetadata](docs/ChartMetadata.md)
 - [Harbor1Client::ChartVersion](docs/ChartVersion.md)
 - [Harbor1Client::ChartVersionDetails](docs/ChartVersionDetails.md)
 - [Harbor1Client::ChartVersions](docs/ChartVersions.md)
 - [Harbor1Client::ComponentHealthStatus](docs/ComponentHealthStatus.md)
 - [Harbor1Client::ComponentOverviewEntry](docs/ComponentOverviewEntry.md)
 - [Harbor1Client::Configurations](docs/Configurations.md)
 - [Harbor1Client::ConfigurationsResponse](docs/ConfigurationsResponse.md)
 - [Harbor1Client::ConfigurationsScanAllPolicy](docs/ConfigurationsScanAllPolicy.md)
 - [Harbor1Client::ConfigurationsScanAllPolicyParameter](docs/ConfigurationsScanAllPolicyParameter.md)
 - [Harbor1Client::ConflictFormatedError](docs/ConflictFormatedError.md)
 - [Harbor1Client::Dependency](docs/Dependency.md)
 - [Harbor1Client::DetailedTag](docs/DetailedTag.md)
 - [Harbor1Client::DigitalSignature](docs/DigitalSignature.md)
 - [Harbor1Client::EmailServerSetting](docs/EmailServerSetting.md)
 - [Harbor1Client::Endpoint](docs/Endpoint.md)
 - [Harbor1Client::FilterStyle](docs/FilterStyle.md)
 - [Harbor1Client::ForbiddenChartAPIError](docs/ForbiddenChartAPIError.md)
 - [Harbor1Client::GCResult](docs/GCResult.md)
 - [Harbor1Client::GeneralInfo](docs/GeneralInfo.md)
 - [Harbor1Client::GeneralInfoClairVulnerabilityStatus](docs/GeneralInfoClairVulnerabilityStatus.md)
 - [Harbor1Client::HasAdminRole](docs/HasAdminRole.md)
 - [Harbor1Client::ImmutableTagRule](docs/ImmutableTagRule.md)
 - [Harbor1Client::InlineResponse200](docs/InlineResponse200.md)
 - [Harbor1Client::InputSecret](docs/InputSecret.md)
 - [Harbor1Client::InsufficientStorageChartAPIError](docs/InsufficientStorageChartAPIError.md)
 - [Harbor1Client::IntegerConfigItem](docs/IntegerConfigItem.md)
 - [Harbor1Client::InternalChartAPIError](docs/InternalChartAPIError.md)
 - [Harbor1Client::IsDefault](docs/IsDefault.md)
 - [Harbor1Client::JobStatus](docs/JobStatus.md)
 - [Harbor1Client::Label](docs/Label.md)
 - [Harbor1Client::Labels](docs/Labels.md)
 - [Harbor1Client::LdapConf](docs/LdapConf.md)
 - [Harbor1Client::LdapFailedImportUsers](docs/LdapFailedImportUsers.md)
 - [Harbor1Client::LdapImportUsers](docs/LdapImportUsers.md)
 - [Harbor1Client::LdapUsers](docs/LdapUsers.md)
 - [Harbor1Client::Manifest](docs/Manifest.md)
 - [Harbor1Client::Namespace](docs/Namespace.md)
 - [Harbor1Client::NativeReportSummary](docs/NativeReportSummary.md)
 - [Harbor1Client::NotFoundChartAPIError](docs/NotFoundChartAPIError.md)
 - [Harbor1Client::OverallHealthStatus](docs/OverallHealthStatus.md)
 - [Harbor1Client::Password](docs/Password.md)
 - [Harbor1Client::Permission](docs/Permission.md)
 - [Harbor1Client::PingRegistry](docs/PingRegistry.md)
 - [Harbor1Client::Project](docs/Project.md)
 - [Harbor1Client::ProjectMember](docs/ProjectMember.md)
 - [Harbor1Client::ProjectMemberEntity](docs/ProjectMemberEntity.md)
 - [Harbor1Client::ProjectMetadata](docs/ProjectMetadata.md)
 - [Harbor1Client::ProjectReq](docs/ProjectReq.md)
 - [Harbor1Client::ProjectScanner](docs/ProjectScanner.md)
 - [Harbor1Client::ProjectSummary](docs/ProjectSummary.md)
 - [Harbor1Client::ProjectSummaryQuota](docs/ProjectSummaryQuota.md)
 - [Harbor1Client::PutRegistry](docs/PutRegistry.md)
 - [Harbor1Client::Quota](docs/Quota.md)
 - [Harbor1Client::QuotaRefObject](docs/QuotaRefObject.md)
 - [Harbor1Client::QuotaSwitcher](docs/QuotaSwitcher.md)
 - [Harbor1Client::QuotaUpdateReq](docs/QuotaUpdateReq.md)
 - [Harbor1Client::Registry](docs/Registry.md)
 - [Harbor1Client::RegistryCredential](docs/RegistryCredential.md)
 - [Harbor1Client::RegistryInfo](docs/RegistryInfo.md)
 - [Harbor1Client::ReplicationExecution](docs/ReplicationExecution.md)
 - [Harbor1Client::ReplicationFilter](docs/ReplicationFilter.md)
 - [Harbor1Client::ReplicationPolicy](docs/ReplicationPolicy.md)
 - [Harbor1Client::ReplicationTask](docs/ReplicationTask.md)
 - [Harbor1Client::ReplicationTrigger](docs/ReplicationTrigger.md)
 - [Harbor1Client::RepoSignature](docs/RepoSignature.md)
 - [Harbor1Client::Report](docs/Report.md)
 - [Harbor1Client::Repository](docs/Repository.md)
 - [Harbor1Client::RepositoryDescription](docs/RepositoryDescription.md)
 - [Harbor1Client::Resource](docs/Resource.md)
 - [Harbor1Client::ResourceList](docs/ResourceList.md)
 - [Harbor1Client::RetagReq](docs/RetagReq.md)
 - [Harbor1Client::RetentionExecution](docs/RetentionExecution.md)
 - [Harbor1Client::RetentionExecutionTask](docs/RetentionExecutionTask.md)
 - [Harbor1Client::RetentionMetadata](docs/RetentionMetadata.md)
 - [Harbor1Client::RetentionPolicy](docs/RetentionPolicy.md)
 - [Harbor1Client::RetentionPolicyScope](docs/RetentionPolicyScope.md)
 - [Harbor1Client::RetentionRule](docs/RetentionRule.md)
 - [Harbor1Client::RetentionRuleMetadata](docs/RetentionRuleMetadata.md)
 - [Harbor1Client::RetentionRuleParamMetadata](docs/RetentionRuleParamMetadata.md)
 - [Harbor1Client::RetentionRuleTrigger](docs/RetentionRuleTrigger.md)
 - [Harbor1Client::RetentionSelector](docs/RetentionSelector.md)
 - [Harbor1Client::RetentionSelectorMetadata](docs/RetentionSelectorMetadata.md)
 - [Harbor1Client::RobotAccount](docs/RobotAccount.md)
 - [Harbor1Client::RobotAccountAccess](docs/RobotAccountAccess.md)
 - [Harbor1Client::RobotAccountCreate](docs/RobotAccountCreate.md)
 - [Harbor1Client::RobotAccountPostRep](docs/RobotAccountPostRep.md)
 - [Harbor1Client::RobotAccountUpdate](docs/RobotAccountUpdate.md)
 - [Harbor1Client::Role](docs/Role.md)
 - [Harbor1Client::RoleParam](docs/RoleParam.md)
 - [Harbor1Client::RoleRequest](docs/RoleRequest.md)
 - [Harbor1Client::ScanOverview](docs/ScanOverview.md)
 - [Harbor1Client::Scanner](docs/Scanner.md)
 - [Harbor1Client::ScannerAdapterMetadata](docs/ScannerAdapterMetadata.md)
 - [Harbor1Client::ScannerCapability](docs/ScannerCapability.md)
 - [Harbor1Client::ScannerRegistration](docs/ScannerRegistration.md)
 - [Harbor1Client::ScannerRegistrationReq](docs/ScannerRegistrationReq.md)
 - [Harbor1Client::ScannerRegistrationSettings](docs/ScannerRegistrationSettings.md)
 - [Harbor1Client::Search](docs/Search.md)
 - [Harbor1Client::SearchRepository](docs/SearchRepository.md)
 - [Harbor1Client::SearchResult](docs/SearchResult.md)
 - [Harbor1Client::SecurityReport](docs/SecurityReport.md)
 - [Harbor1Client::StatisticMap](docs/StatisticMap.md)
 - [Harbor1Client::Stats](docs/Stats.md)
 - [Harbor1Client::Storage](docs/Storage.md)
 - [Harbor1Client::StringConfigItem](docs/StringConfigItem.md)
 - [Harbor1Client::SystemInfo](docs/SystemInfo.md)
 - [Harbor1Client::Tags](docs/Tags.md)
 - [Harbor1Client::TriggerSettings](docs/TriggerSettings.md)
 - [Harbor1Client::UnauthorizedChartAPIError](docs/UnauthorizedChartAPIError.md)
 - [Harbor1Client::User](docs/User.md)
 - [Harbor1Client::UserEntity](docs/UserEntity.md)
 - [Harbor1Client::UserGroup](docs/UserGroup.md)
 - [Harbor1Client::UserProfile](docs/UserProfile.md)
 - [Harbor1Client::UserSearch](docs/UserSearch.md)
 - [Harbor1Client::VulnNamespaceTimestamp](docs/VulnNamespaceTimestamp.md)
 - [Harbor1Client::VulnerabilityItem](docs/VulnerabilityItem.md)
 - [Harbor1Client::VulnerabilitySummary](docs/VulnerabilitySummary.md)
 - [Harbor1Client::WebhookJob](docs/WebhookJob.md)
 - [Harbor1Client::WebhookLastTrigger](docs/WebhookLastTrigger.md)
 - [Harbor1Client::WebhookPolicy](docs/WebhookPolicy.md)
 - [Harbor1Client::WebhookTargetObject](docs/WebhookTargetObject.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

